@@ -13,6 +13,11 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_servicediscovery
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-appmesh", "1.33.0", __name__[0:-6], "aws-appmesh@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
